import box
import pytest
import toml

from simple_semver_toml.cli import cli
from click.testing import CliRunner

@pytest.fixture()
def project_toml(tmp_path):
    toml = """[project]
name = "foo"
version = "0.1.0"
description = "A simple CLI tool to bump versions"

[dependencies]
python = "^3.9"
"""
    p = tmp_path / "pyproject.toml"
    p.write_text(toml)
    return p

@pytest.fixture()
def runner():
    return CliRunner()

def test_version(project_toml, runner):
    result = runner.invoke(cli, ["version", "--path", project_toml])
    assert result.exit_code == 0
    assert "0.1.0" in result.output



@pytest.mark.parametrize("bump_type, expected", [
    ("major", "1.0.0"),
    ("minor", "0.2.0"),
    ("patch", "0.1.1"),
    ("prerelease", "0.1.0-rc.1"),
    ("build", "0.1.0+build.1"),
])
def test_bump(bump_type, expected, project_toml, runner):
    result = runner.invoke(cli, ["bump", "-y", "-q", "--path", project_toml, bump_type])
    assert result.exit_code == 0
    print(project_toml)

    project = box.Box(toml.load(project_toml))
    assert expected == project.project.version
    assert project.dependencies.python == "^3.9"